@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2011  Alexander König
+    Copyright (C) 1999-2014  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
  
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
  
     File: tX_audiofile.cc
  
@@ -25,14 +24,6 @@
 		 the same time. (e.g. tx can now try to load a wavfile
 		 with the builtin routines and if that fails it'll try
 		 to load the file through sox (if available)).
-		 
-    Changes:
-	
-	13 Sept 2002 -	Wrote a seperate loading routine to be used with
-				libmad, which is significantly better then piping mpg?1?.
-				Rewrote load_piped to use realloc() instead - much easier,
-				faster and uses less memory - wish I'd known about realloc()
-				when coding load_piped() for the first time ;)
 */   
 
 
