@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2011  Alexander König
+    Copyright (C) 1999-2014  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -13,18 +13,13 @@
     GNU General Public License for more details.
  
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
  
     File: tX_dialog.cc
  
     Description: Contains the implementation of the Options and About
     		 Dialogs. (And some really ugly "WE WANT TO 
 		 TYPE LESS" macros)
-		 
-    Changes:
-    
-    28 Jul 1999: Now display compiletime settings in the about dialog.
 */    
 
 #include "config.h"
@@ -35,8 +30,8 @@
 #include <string.h>
 #include <gdk/gdk.h>
 #include "tX_icon.h"
-#include "tX_glade_interface.h"
-#include "tX_glade_support.h"
+#include "tX_ui_interface.h"
+#include "tX_ui_support.h"
 
 #include "tX_widget.h"
 #include "tX_flash.h"
@@ -67,7 +62,6 @@ GtkWidget *opt_dialog;
 int opt_hidden=0;
 
 static GtkWidget *last_alsa_device_widget=NULL;
-static GtkWidget *alsa_device_entry=NULL;
 
 void apply_options(GtkWidget *dialog) {
 	/* Audio */
@@ -81,18 +75,24 @@ void apply_options(GtkWidget *dialog) {
 	globals.use_realtime=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "use_realtime")));
 	
 	/* Audio: OSS */
-	strcpy(globals.oss_device, gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(lookup_widget(dialog, "oss_audio_device"))->entry)));
+	char *oss_device = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(lookup_widget(dialog, "oss_audio_device")));
+	if (oss_device) {
+		strcpy(globals.oss_device, oss_device);
+	}
 	globals.oss_buff_no=(int) gtk_spin_button_get_value(GTK_SPIN_BUTTON(lookup_widget(dialog, "oss_buffers")));
 	globals.oss_buff_size=(int) gtk_range_get_value(GTK_RANGE(lookup_widget(dialog, "oss_buffersize")));
-	globals.oss_samplerate=atoi(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(lookup_widget(dialog, "oss_samplerate"))->entry)));
+	globals.oss_samplerate=atoi(gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(lookup_widget(dialog, "oss_samplerate"))));
 	
 	/* Audio: ALSA */
-	strcpy(globals.alsa_device_id, gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(lookup_widget(dialog, "alsa_audio_device"))->entry)));
+	char *alsa_device = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(lookup_widget(dialog, "alsa_audio_device")));
+	if (alsa_device) {
+		strcpy(globals.alsa_device_id, alsa_device);
+	}
 	globals.alsa_buffer_time=(int) gtk_range_get_value(GTK_RANGE(lookup_widget(dialog, "alsa_buffer_time")));
 	globals.alsa_buffer_time*=1000;
 	globals.alsa_period_time=(int) gtk_range_get_value(GTK_RANGE(lookup_widget(dialog, "alsa_period_time")));
 	globals.alsa_period_time*=1000;
-	globals.alsa_samplerate=atoi(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(lookup_widget(dialog, "alsa_samplerate"))->entry)));	
+	globals.alsa_samplerate=atoi(gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(lookup_widget(dialog, "alsa_samplerate"))));	
 	globals.alsa_free_hwstats=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "alsa_free_hwstats")));
 	
 	/* TODO: JACK
@@ -100,7 +100,10 @@ void apply_options(GtkWidget *dialog) {
 	
 	/* Input */
 	globals.xinput_enable=(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "xinput_enable")))==TRUE);
-	strcpy(globals.xinput_device, gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(lookup_widget(dialog, "xinput_device"))->entry)));
+	char *xinput_device = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(lookup_widget(dialog, "xinput_device")));
+	if (xinput_device) {
+		strcpy(globals.xinput_device, xinput_device);
+	}
 	globals.mouse_speed=gtk_range_get_value(GTK_RANGE(lookup_widget(dialog, "mouse_speed")));
 	globals.sense_cycles=(int) gtk_range_get_value(GTK_RANGE(lookup_widget(dialog, "stop_sense_cycles")));
 	globals.vtt_inertia=gtk_range_get_value(GTK_RANGE(lookup_widget(dialog, "vtt_inertia")));
@@ -109,8 +112,9 @@ void apply_options(GtkWidget *dialog) {
 	globals.show_nag=(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "startup_nagbox")))==TRUE);
 	globals.tooltips=(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "mainwin_tooltips")))==TRUE);
 	globals.filename_length=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(lookup_widget(dialog, "filename_length")));
-	if (globals.tooltips) gtk_tooltips_enable(gui_tooltips);
-	else gtk_tooltips_disable(gui_tooltips);
+//	if (globals.tooltips) gtk_tooltips_enable(gui_tooltips);
+//	else gtk_tooltips_disable(gui_tooltips);
+//	TODO: Disable Tooltips no longer possible?
 
 	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "buttons_text_only")))) {
 		globals.button_type=BUTTON_TYPE_TEXT;
@@ -209,16 +213,10 @@ void apply_options(GtkWidget *dialog) {
 	add_widget_dyn(label);
 
 #ifdef USE_ALSA
-static GList *alsa_devices=NULL;
-
-GList *get_alsa_device_list() {
-	if (alsa_devices) {
-		return alsa_devices;
-	}
-	
+void append_alsa_device_list(GtkComboBoxText *combo, char *current) {
 	FILE *file;
 	char buffer[PATH_MAX+1];
-	alsa_devices=NULL;
+	int ctr = 0;
 	
 	if ((file = fopen("/proc/asound/pcm", "r"))) {
 		while(fgets(buffer, PATH_MAX, file)) {
@@ -234,86 +232,85 @@ GList *get_alsa_device_list() {
 				sscanf(buffer, "%i-%i: %1024c", &card, &device, foo);
 				sprintf(tmp, "hw:%i,%i# %s", card, device, foo);
 				
-				alsa_devices=g_list_append (alsa_devices, strdup(tmp));
+				gtk_combo_box_text_append_text(combo, strdup(tmp));
+				
+				if (strcmp(tmp, current) == 0) {
+					gtk_combo_box_set_active(GTK_COMBO_BOX(combo), ctr);
+				}
+				ctr++;
+					
 			}
 		}
 		fclose(file);
 	}
-	
-	return alsa_devices;
 }
 #else
-GList *get_alsa_device_list() {
-	return NULL;
+void append_alsa_device_list(GtkComboBoxText *combo) {
 }
 #endif
 
 
 #ifdef USE_OSS
-static GList *oss_devices=NULL;
-
 int oss_select_dsp_only(const struct dirent *entry){
 	return (strstr(entry->d_name, "dsp")!=0);
 }
 
-GList *get_oss_device_list() {
-	if (oss_devices) {
-		return oss_devices;
-	}
-		
+void append_oss_device_list(GtkComboBoxText *combo, char *current) {
     struct dirent **namelist;
     int n,i;
     n = scandir("/dev", &namelist, oss_select_dsp_only, alphasort);
     
-	oss_devices=NULL;
-	
     if (n>0) {
     	for (i=0; i<n; i++) {
 			char buffer[256];
             sprintf(buffer, "/dev/%s", namelist[i]->d_name);
             free(namelist[i]);
-			oss_devices=g_list_append (oss_devices, strdup(buffer));
+            gtk_combo_box_text_append_text(combo, strdup(buffer));
+            
+            if (strcmp(buffer, current)==0) {
+				gtk_combo_box_set_active(GTK_COMBO_BOX(combo), i);
+			}
 		}
 	}
-	
-	return oss_devices;
 }
 #endif
 
-static GList *sampling_rates=NULL;
+void append_sampling_rates_list(GtkComboBoxText *combo, int current) {
 
-GList *get_sampling_rates_list() {
-	if (sampling_rates) {
-		return sampling_rates;
+	gtk_combo_box_text_append_text(combo,  "22000");
+	gtk_combo_box_text_append_text(combo,  "32000");
+	gtk_combo_box_text_append_text(combo,  "44100");
+	gtk_combo_box_text_append_text(combo,  "48000");
+	switch (current) {
+		case 22000:
+			gtk_combo_box_set_active(GTK_COMBO_BOX(combo), 0);
+			break;
+		case 32000:
+			gtk_combo_box_set_active(GTK_COMBO_BOX(combo), 1);
+			break;
+		case 44100:
+			gtk_combo_box_set_active(GTK_COMBO_BOX(combo), 2);
+			break;
+		case 48000:
+		default:
+			gtk_combo_box_set_active(GTK_COMBO_BOX(combo), 3);
 	}
-
-	sampling_rates=g_list_append(sampling_rates, (void *) "22000");
-	sampling_rates=g_list_append(sampling_rates, (void *) "32000");
-	sampling_rates=g_list_append(sampling_rates, (void *) "44100");
-	sampling_rates=g_list_append(sampling_rates, (void *) "48000");
-
-	return sampling_rates;	
 }
 
-static GList *xinput_devices=NULL;
-
-GList *get_xinput_devices_list() {
-	if (xinput_devices) {
-		return xinput_devices;
-	}
-	
+void append_xinput_devices_list(GtkComboBoxText *combo, char *current) {
 	int devmax;
 	Display *dpy=XOpenDisplay(NULL);
 	XDeviceInfo *xdev=XListInputDevices(dpy, &devmax);
 	XCloseDisplay(dpy);
 
-	for (int i=0; i<devmax; i++) {
-		xinput_devices=g_list_append(xinput_devices, strdup(xdev[i].name));
+	for (int i=0; i<devmax; i++) {		
+		gtk_combo_box_text_append_text(combo, strdup(xdev[i].name));
+		if (strcmp(xdev[i].name, current) == 0) {
+			gtk_combo_box_set_active(GTK_COMBO_BOX(combo), i);
+		}
 	}
 	
 	XFreeDeviceList(xdev);
-	
-	return xinput_devices;
 }
 
 #define MAX_COLORS 10
@@ -328,7 +325,7 @@ char *colors[MAX_COLORS]={ NULL };
 
 
 void init_tx_options(GtkWidget *dialog) {
-	GtkTooltips *tooltips=GTK_TOOLTIPS(lookup_widget(dialog, "tooltips"));
+	char tmp[256];
 	
 	if (colors[0]==NULL) {
 		for (int i=0; i<MAX_COLORS; i++) {
@@ -376,57 +373,41 @@ void init_tx_options(GtkWidget *dialog) {
 #endif	
 	
 	/* Audio: OSS */
-	GList *oss_list=get_oss_device_list();
-	if (oss_list) {
-		gtk_combo_set_popdown_strings(GTK_COMBO(lookup_widget(dialog, "oss_audio_device")), oss_list);
-	}
-	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(lookup_widget(dialog, "oss_audio_device"))->entry), globals.oss_device);
+	append_oss_device_list(GTK_COMBO_BOX_TEXT(lookup_widget(dialog, "oss_audio_device")), globals.oss_device);
 
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(lookup_widget(dialog, "oss_buffers")), globals.oss_buff_no);
 	gtk_range_set_value(GTK_RANGE(lookup_widget(dialog, "oss_buffersize")), globals.oss_buff_size);
-	gtk_tooltips_set_tip(tooltips, lookup_widget(dialog, "oss_buffersize"), "Set the size of the kernel level audio buffers. On slower systems you might have to increase this value (if you hear \"clicks\" or drop-outs). Lower values mean lower latency though.", NULL);	
-	gtk_combo_set_popdown_strings(GTK_COMBO(lookup_widget(dialog, "oss_samplerate")), get_sampling_rates_list());
-	char tmp[64];
-	sprintf(tmp, "%i", globals.oss_samplerate);
-	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(lookup_widget(dialog, "oss_samplerate"))->entry), tmp);
-	
+	gtk_widget_set_tooltip_text(lookup_widget(dialog, "oss_buffersize"), "Set the size of the kernel level audio buffers. On slower systems you might have to increase this value (if you hear \"clicks\" or drop-outs). Lower values mean lower latency though.");	
+	append_sampling_rates_list(GTK_COMBO_BOX_TEXT(lookup_widget(dialog, "oss_samplerate")), globals.oss_samplerate);
 	
 	/* Audio: ALSA */
-	GtkCombo *combo=GTK_COMBO(lookup_widget(dialog, "alsa_audio_device"));
-	GList *alsa_list=get_alsa_device_list();
+	GtkComboBoxText *combo=GTK_COMBO_BOX_TEXT(lookup_widget(dialog, "alsa_audio_device"));
 	last_alsa_device_widget=NULL;
-	alsa_device_entry=combo->entry;
 	
-	if (alsa_list) {
-		gtk_combo_set_popdown_strings(combo, get_alsa_device_list());
-	}
-	gtk_entry_set_text(GTK_ENTRY(combo->entry), globals.alsa_device_id);
+	append_alsa_device_list(GTK_COMBO_BOX_TEXT(combo), globals.alsa_device_id);
 
 	gtk_range_set_value(GTK_RANGE(lookup_widget(dialog, "alsa_buffer_time")), globals.alsa_buffer_time/1000);
-	gtk_tooltips_set_tip(tooltips, lookup_widget(dialog, "alsa_buffer_time"), "Sets the size of the ALSA ring buffer. On slower systems you might have to increase this value (if you hear \"clicks\" or drop-outs). Lower values mean lower latency though.", NULL);	
+	gtk_widget_set_tooltip_text(lookup_widget(dialog, "alsa_buffer_time"), "Sets the size of the ALSA ring buffer. On slower systems you might have to increase this value (if you hear \"clicks\" or drop-outs). Lower values mean lower latency though.");	
 	gtk_range_set_value(GTK_RANGE(lookup_widget(dialog, "alsa_period_time")), globals.alsa_period_time/1000);
-	gtk_tooltips_set_tip(tooltips, lookup_widget(dialog, "alsa_period_time"), "The ALSA period time determines how much audio data will be written to the device at once. It is recommended to set this value to a half or a third of the ALSA buffer time.", NULL);	
+	gtk_widget_set_tooltip_text(lookup_widget(dialog, "alsa_period_time"), "The ALSA period time determines how much audio data will be written to the device at once. It is recommended to set this value to a half or a third of the ALSA buffer time.");	
 
-	gtk_combo_set_popdown_strings(GTK_COMBO(lookup_widget(dialog, "alsa_samplerate")), get_sampling_rates_list());
-	sprintf(tmp, "%i", globals.alsa_samplerate);
-	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(lookup_widget(dialog, "alsa_samplerate"))->entry), tmp);
+	append_sampling_rates_list(GTK_COMBO_BOX_TEXT(lookup_widget(dialog, "alsa_samplerate")), globals.alsa_samplerate);
 	
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "alsa_free_hwstats")), globals.alsa_free_hwstats);
 	
 	/* Input */
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(dialog, "xinput_enable")), globals.xinput_enable);
 	
-	gtk_combo_set_popdown_strings(GTK_COMBO(lookup_widget(dialog, "xinput_device")), get_xinput_devices_list());
-	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(lookup_widget(dialog, "xinput_device"))->entry), globals.xinput_device);
+	append_xinput_devices_list(GTK_COMBO_BOX_TEXT(lookup_widget(dialog, "xinput_device")), globals.xinput_device);
 
 	gtk_range_set_value(GTK_RANGE(lookup_widget(dialog, "mouse_speed")), globals.mouse_speed);
-	gtk_tooltips_set_tip(tooltips, lookup_widget(dialog, "mouse_speed"), "The speed of your mouse in scratch mode. Use negative values to invert motion.", NULL);
+	gtk_widget_set_tooltip_text(lookup_widget(dialog, "mouse_speed"), "The speed of your mouse in scratch mode. Use negative values to invert motion.");
 	
 	gtk_range_set_value(GTK_RANGE(lookup_widget(dialog, "stop_sense_cycles")), globals.sense_cycles);
-	gtk_tooltips_set_tip(tooltips, lookup_widget(dialog, "stop_sense_cycles"),"If there is no \"motion-event\" for x cycles, where x is the number of cycles you select here, terminatorX assumes mouse motion has stopped. For smaller buffer sizes (=> shorter cycle times) you might have to increase this value", NULL);	
+	gtk_widget_set_tooltip_text(lookup_widget(dialog, "stop_sense_cycles"),"If there is no \"motion-event\" for x cycles, where x is the number of cycles you select here, terminatorX assumes mouse motion has stopped. For smaller buffer sizes (=> shorter cycle times) you might have to increase this value");	
 
 	gtk_range_set_value(GTK_RANGE(lookup_widget(dialog, "vtt_inertia")), globals.vtt_inertia);
-	gtk_tooltips_set_tip(tooltips, lookup_widget(dialog, "vtt_inertia"),"This value defines how fast the turntables will adapt to the speed input - the higher this value, the longer it will take the turntable to actually reach the target speed.", NULL);	
+	gtk_widget_set_tooltip_text(lookup_widget(dialog, "vtt_inertia"),"This value defines how fast the turntables will adapt to the speed input - the higher this value, the longer it will take the turntable to actually reach the target speed.");	
 
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(lookup_widget(dialog, "filename_length")), globals.filename_length);
 
@@ -449,11 +430,11 @@ void init_tx_options(GtkWidget *dialog) {
 	}
 	
 	gtk_range_set_value(GTK_RANGE(lookup_widget(dialog, "update_delay")), globals.update_delay);
-	gtk_tooltips_set_tip(tooltips, lookup_widget(dialog, "update_delay"), "How often to update the slow widgets.", NULL);	
+	gtk_widget_set_tooltip_text(lookup_widget(dialog, "update_delay"), "How often to update the slow widgets.");	
 	gtk_range_set_value(GTK_RANGE(lookup_widget(dialog, "update_idle")), globals.update_idle);
-	gtk_tooltips_set_tip(tooltips, lookup_widget(dialog, "update_idle"), "The update thread will idle for the selcted amount of milliseconds. If you want to have a more responsive display update reduce this value - if you have performance problems increase this value.", NULL);	
+	gtk_widget_set_tooltip_text(lookup_widget(dialog, "update_idle"), "The update thread will idle for the selcted amount of milliseconds. If you want to have a more responsive display update reduce this value - if you have performance problems increase this value.");	
 	gtk_range_set_value(GTK_RANGE(lookup_widget(dialog, "vumeter_decay")), globals.flash_response);
-	gtk_tooltips_set_tip(tooltips, lookup_widget(dialog, "vumeter_decay"), "Defines how fast the maximum values of the VU meters should be decayed.", NULL);	
+	gtk_widget_set_tooltip_text(lookup_widget(dialog, "vumeter_decay"), "Defines how fast the maximum values of the VU meters should be decayed.");	
 
 	/* Audio Colors */
 	int ctr=0;
@@ -494,7 +475,7 @@ void create_options()
 void display_options()
 {
 	if (opt_dialog) {
-		gdk_window_raise(opt_dialog->window);	
+		gdk_window_raise(gtk_widget_get_window(opt_dialog));	
 	} else {
 		create_options();
 	}
@@ -504,7 +485,7 @@ GtkWidget *about=NULL;
 
 void raise_about()
 {
-	if (about) gdk_window_raise(about->window);
+	if (about) gdk_window_raise(gtk_widget_get_window(about));
 }
 
 
@@ -529,16 +510,16 @@ void show_about(int nag)
 	GtkWidget *window;
 	GtkWidget *btn;
 	GtkWidget *box;
-	GtkWidget *hbox;
 	GtkWidget *label;
 	GtkWidget *sep;
 	GtkWidget *text;
 	GtkWidget *scroll;
 	GtkWidget *iwid;
+	GtkWidget *expander;
 	
 	/* Only raise the window if it's already open... */
 	if (about)  {
-		gdk_window_raise(about->window);
+		gdk_window_raise(gtk_widget_get_window(about));
 		return;
 	}
 	
@@ -567,7 +548,7 @@ void show_about(int nag)
 		gtk_misc_set_alignment(GTK_MISC(label), 0.1, 0.5);
 		gtk_widget_show(label);
 
-		label=gtk_label_new("Copyright (C) 1999-2011 by Alexander König");
+		label=gtk_label_new("Copyright (C) 1999-2014 by Alexander König");
 		gtk_box_pack_start(GTK_BOX(box2), label, WID_DYN);
 		gtk_misc_set_alignment(GTK_MISC(label), 0.9, 0.5);
 		gtk_widget_show(label);
@@ -585,121 +566,72 @@ void show_about(int nag)
 		sep=gtk_hseparator_new();
 		add_about_wid_fix(sep);
 		
-		label=gtk_label_new("This is "PACKAGE" release "VERSION" - Copyright (C) 1999-2011 by Alexander König"
-		"\nSend comments, patches and scratches to: alex@lisas.de\nterminatorX-homepage: http://www.terminatorX.org");
+		label=gtk_label_new("This is "PACKAGE" release "VERSION".\nCopyright (C) 1999-2014 by Alexander König <alex@lisas.de>");
 
 		gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
 		add_about_wid_fix(label);
 
 		sep=gtk_hseparator_new();
 		add_about_wid_fix(sep);
-		
-		label=gtk_label_new(
-		"Compilation flags: "
-		"sox: "
+
+		expander = gtk_expander_new("Build info");
+		GtkWidget *exbox=gtk_vbox_new(FALSE, 2);
+		gtk_container_add(GTK_CONTAINER(expander), exbox);
+		gtk_widget_show(exbox);
+
+		label=gtk_label_new("Compilation flags: "
 #ifdef USE_SOX_INPUT
-		"ON"
-#else
-	 	"OFF"
-#endif		
-		" - mpg123: "
+		" [sox]"
+#endif
 #ifdef USE_MPG123_INPUT
-		"ON"
-#else
-		"OFF"
+		" [mpg123]"
 #endif
-		" - ogg123: "
 #ifdef USE_OGG123_INPUT
-		"ON"
-#else
-		"OFF"
+		" [ogg123]"
 #endif
-		" - libmad: "
 #ifdef USE_MAD_INPUT
-		"ON"
-#else
-		"OFF"
+		" [mad]"
 #endif
-
-		" - libvorbis: "
 #ifdef USE_VORBIS_INPUT
-		"ON"
-#else
-		"OFF"
+		" [vorbis]"
 #endif
-
-		" - libaudiofile: "
 #ifdef USE_AUDIOFILE_INPUT
-		"ON"
-#else
-		"OFF"
+		" [audiofile]"
 #endif
-
-		" - MIDI: "
 #ifdef USE_ALSA_MIDI_IN
-		"ON"
-#else
-		"OFF"
+		" [midi]"
 #endif
-
-		" - OSS: "
 #ifdef USE_OSS
-		"ON"
-#else
-		"OFF"
+		" [oss]"
 #endif
-
-		" - ALSA: "
 #ifdef USE_ALSA
-		"ON"
-#else
-		"OFF"
+		" [alsa]"
 #endif
-
-		" - JACK: "
 #ifdef USE_JACK
-		"ON"
-#else
-		"OFF"
+		" [jack]"
 #endif
-
-		" - liblrdf: "
 #ifdef USE_LRDF
-		"ON"
-#else
-		"OFF"
+		" [lrdf]"
 #endif
-
-		" - rt scheduling: "
 #ifdef USE_SCHEDULER
-		"ON"
-#else
-		"OFF"
+		" [rt]"
 #endif
-
-		" - capabilities: "
 #ifdef USE_CAPABILITIES
-		"ON"
-#else
-		"OFF"
+		" [cap]"
 #endif
-
-		" - "
-#ifdef WORDS_BIGENDIAN
-		"big"
-#else
-		"little"
-#endif
-		" endian.");
+		"");
 	
 		gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
 		gtk_widget_set_size_request(label, 640, -1);
 		gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
-		add_about_wid_fix(label);
+		gtk_container_add(GTK_CONTAINER(exbox), label);
+		gtk_widget_show(label);
+		add_about_wid_fix(expander);
 
 #ifdef 	USE_SCHEDULER
 		sep=gtk_hseparator_new();
-		add_about_wid_fix(sep);
+		gtk_widget_show(sep);
+		gtk_container_add(GTK_CONTAINER(exbox), sep);
 
 		char buffer[4096];
 		
@@ -708,6 +640,7 @@ void show_about(int nag)
 		
 		pthread_getschedparam(tX_engine::get_instance()->get_thread_id(), &policy, &parm);
 		char prio_str[32]="";
+		bool s_enabled = false;
 		
 		switch (policy) {
 			case SCHED_OTHER:
@@ -720,28 +653,28 @@ void show_about(int nag)
 			
 			case SCHED_FIFO:
 				strcpy(prio_str, "SCHED_FIFO");
+				s_enabled = true;
 				break;
 			
 			default:
 				sprintf(prio_str, "UNKOWN (%i)", policy);
 		}
 		
-		sprintf(buffer, "Audio engine scheduling policy: %s.\n(Note: SCHED_FIFO equals realtime scheduling.)", prio_str);
+		sprintf(buffer, "Audio engine scheduling policy: %s.\nScheduling with realtime priority is %s.", prio_str, s_enabled ? "enabled" : "disabled");
 
 		label=gtk_label_new(buffer);
 
 		gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
-		add_about_wid_fix(label);
+		gtk_widget_show(label);
+		gtk_container_add(GTK_CONTAINER(exbox), label);
 #endif
 
 		sep=gtk_hseparator_new();
 		add_about_wid_fix(sep);
 
-		label=gtk_label_new("License (GPL V2):");
-		gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
-		add_about_wid_fix(label);
+		expander = gtk_expander_new("License (GPL V2):");
 
-		hbox=gtk_hbox_new(FALSE, 5);		
+		add_about_wid_fix(expander);
 
 		GtkTextIter iter;
 		GtkTextBuffer *tbuffer;
@@ -763,11 +696,9 @@ void show_about(int nag)
 		gtk_widget_set_size_request(GTK_WIDGET(text), 640, 200);
 		gtk_widget_show(text);		
 		
-		gtk_box_pack_start(GTK_BOX(hbox), scroll, WID_DYN);
+		gtk_container_add(GTK_CONTAINER(expander), scroll);
 		gtk_widget_show(scroll);		
 		
-		add_about_wid(hbox);
-
 		sep=gtk_hseparator_new();
 		add_about_wid_fix(sep);
 
@@ -777,8 +708,8 @@ void show_about(int nag)
 		gtk_container_add(GTK_CONTAINER(window), box);
 		gtk_widget_show(box);
 		
-		g_signal_connect(G_OBJECT(btn), "clicked", (GtkSignalFunc) destroy_about, NULL);		
-		g_signal_connect(G_OBJECT(window), "delete-event", (GtkSignalFunc) destroy_about, NULL);		
+		g_signal_connect(G_OBJECT(btn), "clicked", (GCallback) destroy_about, NULL);		
+		g_signal_connect(G_OBJECT(window), "delete-event", (GCallback) destroy_about, NULL);		
 	}
 	gtk_widget_show(window);	
 	tX_set_icon(window);
