@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2011  Alexander König
+    Copyright (C) 1999-2014  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
  
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
  
     File: tX_mastergui.cc
  
@@ -42,8 +41,8 @@
 #include "tX_sequencer.h"
 #include "tX_mastergui.h"
 #include "tX_knobloader.h"
-#include "tX_glade_interface.h"
-#include "tX_glade_support.h"
+#include "tX_ui_interface.h"
+#include "tX_ui_support.h"
 #include <sys/time.h>
 #include <sys/wait.h>
 #include "tX_midiin.h"
@@ -59,6 +58,10 @@
 #define TX_SET_ID_13 "terminatorX turntable set file - version 1.3 - data:"
 #define TX_SET_ID_14 "terminatorX turntable set file - version 1.4 - data:"
 
+#define BROWSER1 "xdg-open"
+#define BROWSER2 "x-www-browser"
+#define BROWSER3 "firefox"
+
 int audioon=0;
 int sequencer_ready=1;
 
@@ -101,9 +104,9 @@ GtkWidget *fullscreen_item;
 int rec_dont_care=0;
 gint update_tag;
 
-#define connect_entry(wid, func, ptr); g_signal_connect(G_OBJECT(wid), "activate", (GtkSignalFunc) func, (void *) ptr);
-#define connect_adj(wid, func, ptr); g_signal_connect(G_OBJECT(wid), "value_changed", (GtkSignalFunc) func, (void *) ptr);
-#define connect_button(wid, func, ptr); g_signal_connect(G_OBJECT(wid), "clicked", (GtkSignalFunc) func, (void *) ptr);
+#define connect_entry(wid, func, ptr); g_signal_connect(G_OBJECT(wid), "activate", (GCallback) func, (void *) ptr);
+#define connect_adj(wid, func, ptr); g_signal_connect(G_OBJECT(wid), "value_changed", (GCallback) func, (void *) ptr);
+#define connect_button(wid, func, ptr); g_signal_connect(G_OBJECT(wid), "clicked", (GCallback) func, (void *) ptr);
 
 Window x_window;
 GdkWindow* top_window;
@@ -138,11 +141,9 @@ int last_grab_status=0;
 GtkWidget *delete_all_item=NULL;
 GtkWidget *delete_all_vtt_item=NULL;
 
-GtkTooltips *gui_tooltips=NULL;
-
 void gui_set_tooltip(GtkWidget *wid, const char *tip)
 {
-	gtk_tooltips_set_tip(gui_tooltips, wid, tip, NULL);
+	gtk_widget_set_tooltip_text(wid, tip);
 }
 
 void turn_audio_off(void)
@@ -228,9 +229,7 @@ void mg_update_status()
 	procfs=fopen(filename, "r");
 	if (procfs) {
 		while((!feof(procfs)) && !found) {
-			char *res = fgets(buffer, 256, procfs);
-			
-			if (strncmp(TX_MEMTAG, buffer, sizeof(TX_MEMTAG)-1)==0) {
+			if (fgets(buffer, 256, procfs) && (strncmp(TX_MEMTAG, buffer, sizeof(TX_MEMTAG)-1)==0)) {
 				found=1;
 				sscanf(buffer, TX_MEMTAG" %i kB", &mem);
 				sprintf(buffer, "%.1lf M", ((double) mem)/1024.0);
@@ -246,7 +245,7 @@ void mg_update_status()
 	gtk_label_set_text(GTK_LABEL(no_of_vtts), buffer);*/
 }
 
-GtkSignalFunc new_table(GtkWidget *, char *fn)
+GCallback new_table(GtkWidget *, char *fn)
 {
 	//turn_audio_off();
 		
@@ -270,10 +269,10 @@ GtkSignalFunc new_table(GtkWidget *, char *fn)
 bool tx_mg_have_setname=false;
 char tx_mg_current_setname[PATH_MAX]="";
 
-GtkSignalFunc new_tables() {
+GCallback new_tables() {
 	GtkWidget *dialog=gtk_message_dialog_new(GTK_WINDOW(main_window), 
 		GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO,
-		"Are you sure you want to loose all turntables and events?");
+		"Are you sure you want to lose all turntables and events?");
 	
 	int res=gtk_dialog_run(GTK_DIALOG(dialog));
 	gtk_widget_destroy(dialog);
@@ -296,7 +295,7 @@ GtkSignalFunc new_tables() {
 
 /* Loading saved setups */
 #ifndef USE_FILECHOOSER
-GtkSignalFunc cancel_load_tables(GtkWidget *wid)
+GCallback cancel_load_tables(GtkWidget *wid)
 {
 	gtk_widget_destroy(load_dialog);
 	load_dialog=NULL;
@@ -397,7 +396,7 @@ void do_load_tables(GtkWidget *wid)
 }
 #endif
 
-GtkSignalFunc load_tables()
+GCallback load_tables()
 {
 #ifdef USE_FILECHOOSER	
 	GtkWidget * dialog = gtk_file_chooser_dialog_new ("Open Set File",
@@ -465,8 +464,9 @@ vtt_class* choose_vtt() {
 
 	GtkWidget *label = gtk_label_new ("Select turntable to load audio file to:");
 	gtk_widget_show(label);
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox), label);
-	gtk_container_set_border_width(GTK_CONTAINER (GTK_DIALOG(dialog)->vbox), 10);
+
+	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area(GTK_DIALOG(dialog))), label);
+	gtk_container_set_border_width(GTK_CONTAINER (gtk_dialog_get_content_area(GTK_DIALOG(dialog))), 10);
 	
 	list <GtkWidget *> radio_buttons;
 	list <vtt_class *> :: iterator iter;
@@ -484,7 +484,7 @@ vtt_class* choose_vtt() {
 			radio = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(radio), (*iter)->name);
 		}
 		g_object_set_data(G_OBJECT(radio), "tX_vtt", (*iter));
-		gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox), radio);
+		gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area(GTK_DIALOG(dialog))), radio);
 		gtk_widget_show(radio);
 		radio_buttons.push_back(radio);
 	}	
@@ -513,7 +513,7 @@ vtt_class* choose_vtt() {
 }
 
 
-GtkSignalFunc load_audio() {
+GCallback load_audio() {
 	vtt_class *vtt = NULL;
 	
 	pthread_mutex_lock(&vtt_class::render_lock);
@@ -531,21 +531,21 @@ GtkSignalFunc load_audio() {
 	return NULL;
 }
 
-GtkSignalFunc drop_set(GtkWidget *widget, GdkDragContext *context,
+GCallback drop_set(GtkWidget *widget, GdkDragContext *context,
 		gint x, gint y, GtkSelectionData *selection_data,
 		guint info, guint time, vtt_class *vtt)
 {
 	char filename[PATH_MAX];
 	char *fn;
 	
-	strncpy(filename, (char *) selection_data->data, (size_t) selection_data->length);
-	filename[selection_data->length]=0;
+	strncpy(filename, (char *) gtk_selection_data_get_data(selection_data), (size_t) gtk_selection_data_get_length(selection_data));
+	filename[gtk_selection_data_get_length(selection_data)]=0;
 
 	fn = strchr (filename, '\r');
 	*fn=0;	
 	
 	fn = strchr (filename, ':');
-	if (fn) fn++; else fn=(char *) selection_data->data;
+	if (fn) fn++; else fn=(char *) gtk_selection_data_get_data(selection_data);
 	
 	load_tt_part(fn);
 
@@ -556,7 +556,7 @@ GtkSignalFunc drop_set(GtkWidget *widget, GdkDragContext *context,
 /* save tables */
 
 #ifndef USE_FILECHOOSER
-GtkSignalFunc cancel_save_tables(GtkWidget *wid)
+GCallback cancel_save_tables(GtkWidget *wid)
 {
 	gtk_widget_destroy(save_dialog);
 	save_dialog=NULL;
@@ -627,7 +627,7 @@ void do_save_tables(char *buffer)
 	}
 }
 
-GtkSignalFunc save_tables_as()
+GCallback save_tables_as()
 {
 #ifdef USE_FILECHOOSER
 	GtkWidget * dialog = gtk_file_chooser_dialog_new ("Save Set",
@@ -672,7 +672,7 @@ GtkSignalFunc save_tables_as()
 	return NULL;
 }
 
-GtkSignalFunc save_tables()
+GCallback save_tables()
 {
 	if (!tx_mg_have_setname) {
 		save_tables_as();
@@ -683,15 +683,15 @@ GtkSignalFunc save_tables()
 	return NULL;
 }
 
-GtkSignalFunc master_volume_changed (GtkWidget *wid, void *d)
+GCallback master_volume_changed (GtkWidget *wid, void *d)
 {
-	sp_master_volume.receive_gui_value((float) GTK_ADJUSTMENT(wid)->value);
+	sp_master_volume.receive_gui_value((float) gtk_adjustment_get_value(GTK_ADJUSTMENT(wid)));
 	return NULL;	
 }
 
-GtkSignalFunc master_pitch_changed(GtkWidget *wid, void *d)
+GCallback master_pitch_changed(GtkWidget *wid, void *d)
 {
-	sp_master_pitch.receive_gui_value((float) GTK_ADJUSTMENT(wid)->value);	
+	sp_master_pitch.receive_gui_value((float) gtk_adjustment_get_value(GTK_ADJUSTMENT(wid)));	
 	return NULL;	
 }
 
@@ -708,11 +708,11 @@ void mg_enable_critical_buttons(int enable)
 	vg_enable_critical_buttons(enable);
 }
 
-GtkSignalFunc seq_stop(GtkWidget *w, void *);
+GCallback seq_stop(GtkWidget *w, void *);
 
 static bool stop_override=false;
 
-GtkSignalFunc audio_on(GtkWidget *w, void *d)
+GCallback audio_on(GtkWidget *w, void *d)
 {
 	tX_engine_error res;
 	
@@ -747,7 +747,7 @@ GtkSignalFunc audio_on(GtkWidget *w, void *d)
 		stop_update=0;
 		audioon=1;
 		update_delay=globals.update_delay;
-		update_tag=gtk_timeout_add(globals.update_idle, (GtkFunction) pos_update, NULL);
+		update_tag=g_timeout_add(globals.update_idle, (GSourceFunc) pos_update, NULL);
 		gtk_widget_set_sensitive(grab_button, 1);
 	} else {	
 		if (stop_override) return NULL;
@@ -777,7 +777,7 @@ GtkSignalFunc audio_on(GtkWidget *w, void *d)
 	return NULL;
 }
 
-GtkSignalFunc cancel_rec(GtkWidget *wid)
+GCallback cancel_rec(GtkWidget *wid)
 {
 	gtk_widget_destroy(rec_dialog);
 	rec_dialog=NULL;
@@ -790,7 +790,7 @@ void do_rec(GtkWidget *wid)
 {
 	char buffer[PATH_MAX];
 	
-	strcpy(buffer, gtk_file_selection_get_filename(GTK_FILE_SELECTION(rec_dialog)));
+	strcpy(buffer, gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(rec_dialog)));
 
 	if (strlen(buffer)) {
 		strcpy(globals.record_filename, buffer);		
@@ -806,7 +806,7 @@ void do_rec(GtkWidget *wid)
 	rec_dialog_win=NULL;
 }
 
-GtkSignalFunc select_rec_file()
+GCallback select_rec_file()
 {
 #ifdef USE_FILECHOOSER
 	GtkWidget * dialog = gtk_file_chooser_dialog_new ("Record To Disk",
@@ -858,7 +858,7 @@ GtkSignalFunc select_rec_file()
 	return NULL;
 }
 
-GtkSignalFunc tape_on(GtkWidget *w, void *d)
+GCallback tape_on(GtkWidget *w, void *d)
 {
 	if (rec_dont_care) return 0;
 
@@ -894,7 +894,7 @@ gboolean quit()
 	if (globals.quit_confirm) {
 		GtkWidget *dialog=gtk_message_dialog_new(GTK_WINDOW(main_window), 
 		GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO,
-		"Exit terminatorX and loose all unsaved data?");
+		"Exit terminatorX and lose all unsaved data?");
 		
 		int res=gtk_dialog_run(GTK_DIALOG(dialog));
 		gtk_widget_destroy(dialog);
@@ -909,10 +909,13 @@ gboolean quit()
 	turn_audio_off();
 	vtt_class::delete_all();
 
-	if (update_tag)
-	gtk_timeout_remove(update_tag);
-	globals.width=main_window->allocation.width;
-	globals.height=main_window->allocation.height;
+	if (update_tag) {
+		g_source_remove(update_tag);
+	}
+	GtkAllocation allocation;
+	gtk_widget_get_allocation(GTK_WIDGET(main_window), &allocation);
+	globals.width=allocation.width;
+	globals.height=allocation.height;
 
 	gtk_main_quit();
 	
@@ -925,7 +928,7 @@ void mplcfitx()
 	show_about(0);
 }
 
-GtkSignalFunc seq_play(GtkWidget *w, void *)
+GCallback seq_play(GtkWidget *w, void *)
 {
 	if ((sequencer.is_empty()) && 	(!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(seq_rec_btn)))) {
 		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(w)))
@@ -946,7 +949,7 @@ GtkSignalFunc seq_play(GtkWidget *w, void *)
 	return NULL;
 }
 
-GtkSignalFunc seq_stop(GtkWidget *w, void *)
+GCallback seq_stop(GtkWidget *w, void *)
 {
 	if (!sequencer_ready) return NULL;
 	sequencer.trig_stop();
@@ -964,7 +967,7 @@ GtkSignalFunc seq_stop(GtkWidget *w, void *)
 	return NULL;
 }
 
-GtkSignalFunc seq_rec(GtkWidget *w, void *)
+GCallback seq_rec(GtkWidget *w, void *)
 {
 	seq_adj_care=0;
 	gtk_widget_set_sensitive(seq_slider, 0);
@@ -1025,7 +1028,7 @@ void sequencer_move(GtkWidget *wid, void *d)
 	guint32 pos;
 	
 	if (seq_adj_care) {
-		pos=sequencer.set_start_timestamp((float) GTK_ADJUSTMENT(wid)->value);
+		pos=sequencer.set_start_timestamp((float) gtk_adjustment_get_value(GTK_ADJUSTMENT(wid)));
 		seq_update_entry(pos);	
 	}
 }
@@ -1426,8 +1429,6 @@ void create_mastergui(int x, int y)
 	GtkWidget *status_box;
 	GtkWidget *wrapbox;
 	
-	gui_tooltips=gtk_tooltips_new();
-
 	main_window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
 	gtk_window_set_wmclass(GTK_WINDOW(main_window), "terminatorX", "tX_mastergui");
@@ -1543,7 +1544,7 @@ void create_mastergui(int x, int y)
 	dummy=gtk_hscale_new(dumadj);
 	gtk_widget_set_size_request(dummy, 65, 20);
 	seq_slider=dummy;
-	g_signal_connect(G_OBJECT(seq_slider), "button-release-event", (GtkSignalFunc) seq_slider_released, NULL);
+	g_signal_connect(G_OBJECT(seq_slider), "button-release-event", (GCallback) seq_slider_released, NULL);
 	gtk_scale_set_draw_value(GTK_SCALE(dummy), FALSE);
 	
 	gui_set_tooltip(dummy, "Select the start position for the sequencer in song-time.");
@@ -1621,7 +1622,7 @@ void create_mastergui(int x, int y)
 	dummy=gtk_vscale_new(dumadj);
 	gtk_range_set_inverted(GTK_RANGE(dummy), TRUE);
 	gtk_scale_set_draw_value(GTK_SCALE(dummy), False);
-	g_signal_connect(G_OBJECT(dummy), "button_press_event", (GtkSignalFunc) tX_seqpar::tX_seqpar_press, &sp_master_volume);	
+	g_signal_connect(G_OBJECT(dummy), "button_press_event", (GCallback) tX_seqpar::tX_seqpar_press, &sp_master_volume);	
 	
 	gtk_box_pack_end(GTK_BOX(master_vol_box), dummy, WID_FIX);
 	gtk_widget_show(dummy);	
@@ -1696,10 +1697,11 @@ void create_mastergui(int x, int y)
 
 	new_table(NULL, NULL); // to give the user something to start with ;)
 
-	g_signal_connect (G_OBJECT(main_window), "delete-event", (GtkSignalFunc) quit, NULL);
+	g_signal_connect (G_OBJECT(main_window), "delete-event", (GCallback) quit, NULL);
 	
-	if (globals.tooltips) gtk_tooltips_enable(gui_tooltips);
-	else gtk_tooltips_disable(gui_tooltips);
+//	if (globals.tooltips) gtk_tooltips_enable(gui_tooltips);
+//	else gtk_tooltips_disable(gui_tooltips);
+//  TODO: Check for global enable/disable of tooltips
 }
 
 gfloat old_percent=-1;
@@ -1755,8 +1757,8 @@ void remove_from_panel_bar(GtkWidget *button)
 
 void fullscreen_toggle(GtkCheckMenuItem *item, gpointer data) {
 	XEvent xev;
-	Window win=GDK_WINDOW_XID(main_window->window);
-	Display *disp=GDK_WINDOW_XDISPLAY(main_window->window);
+	Window win = GDK_WINDOW_XID(gtk_widget_get_window(main_window));
+	Display *disp=GDK_WINDOW_XDISPLAY(gtk_widget_get_window(main_window));
 	
 	globals.fullscreen_enabled=gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(fullscreen_item));
 	
@@ -1784,7 +1786,7 @@ void fullscreen_toggle(GtkCheckMenuItem *item, gpointer data) {
 	xev.xclient.data.l[0] = globals.fullscreen_enabled ? _NET_WM_STATE_ADD : _NET_WM_STATE_REMOVE;
 	xev.xclient.data.l[1] = gdk_x11_atom_to_xatom (gdk_atom_intern ("_NET_WM_STATE_FULLSCREEN", TRUE));
 	xev.xclient.data.l[2] = gdk_x11_atom_to_xatom (GDK_NONE);
-	XSendEvent(gdk_display, GDK_WINDOW_XID (gdk_get_default_root_window ()),
+	XSendEvent(gdk_x11_get_default_xdisplay(), GDK_WINDOW_XID (gdk_get_default_root_window ()),
 		False, SubstructureRedirectMask | SubstructureNotifyMask,
 		&xev);	
 }
@@ -1804,15 +1806,15 @@ void display_mastergui()
 	gtk_widget_show(main_window);
 	fullscreen_setup();	
 	top=gtk_widget_get_toplevel(main_window);
-	top_window=GDK_WINDOW(top->window);
-	x_window=GDK_WINDOW_XWINDOW(top->window);
+	top_window=GDK_WINDOW(gtk_widget_get_window(top));
+	x_window=GDK_WINDOW_XWINDOW(gtk_widget_get_window(top));
 }
 
 pid_t help_child=0;
 GTimer *help_timer=NULL;
 int help_tag=-1;
 
-int help_checker()
+gboolean help_checker()
 {
 	gdouble time;
 	gulong ms;
@@ -1824,14 +1826,16 @@ int help_checker()
 		if (time > 5) {
 			/* 5 seconds and it's still running - so we assume everything's OK. */
 			tX_debug("No longer waiting for gnome-help..");
-			gtk_idle_remove(help_tag);
+			g_source_remove(help_tag);
 			help_tag=-1;
 		}
-	} else {
-		/* We are still here and the child exited - that could mean trouble. */
-		tx_note("Couldn't run the gnome-help command (alias \"yelp\") to display the terminatorX manual. Please ensure that \"yelp\" is installed.", true);		
+	}  else {
+		//yelp waitpid status does not allow determining success
+		//printf("%i %i\n", WIFEXITED(status), WEXITSTATUS(status));
+		///* We are still here and the child exited - that could mean trouble. */
+		//tx_note("Couldn't run the gnome-help command (alias \"yelp\") to display the terminatorX manual. Please ensure that \"yelp\" is installed.", true);		
 		
-		gtk_idle_remove(help_tag);
+		g_source_remove(help_tag);
 		help_tag=-1;
 	}
 	return TRUE;	
@@ -1846,7 +1850,7 @@ void display_help()
 	help_child=fork();
 
 	if (help_tag!=-1) {
-		gtk_idle_remove(help_tag);
+		g_source_remove(help_tag);
 		if (help_timer) g_timer_destroy(help_timer);
 		help_child=0;
 		help_tag=-1;
@@ -1855,8 +1859,7 @@ void display_help()
 	
 	if (help_child==0) {
 		// child
-		// execlp("gnome-help","gnome-help","ghelp:/" INSTALL_PREFIX "/terminatorX/doc/terminatorX-manual/C/terminatorX-manual.xml", NULL);
-		execlp("gnome-help","gnome-help","ghelp://" XML_MANUAL, NULL);		
+		execlp("gnome-help","gnome-help","file://" XML_MANUAL, NULL);		
 		_exit(-1);
 	} else if (help_child==-1) {
 		tx_note("System error: couldn't fork() to run the help process.", true);
@@ -1864,7 +1867,7 @@ void display_help()
 		help_timer=g_timer_new();
 		g_timer_start(help_timer);
 	
-		help_tag=gtk_idle_add((GtkFunction) help_checker, NULL);
+		help_tag=g_idle_add((GSourceFunc) help_checker, NULL);
 	}
 }
 
@@ -1872,58 +1875,19 @@ pid_t browser_child=0;
 GTimer *browser_timer=NULL;
 int browser_tag=-1;
 
-int browser_checker()
-{
-	gdouble time;
-	gulong ms;
-	int status;
-	int result=waitpid(browser_child, &status, WNOHANG);
-	
-	if (result==0) {
-		time=g_timer_elapsed(browser_timer, &ms);
-		if (time > 5) {
-			/* 5 seconds and it's still running - so we assume everything's OK. */
-			tX_debug("No longer waiting for a browser..");
-			gtk_idle_remove(browser_tag);
-			browser_tag=-1;
-		}
-	} else {
-		/* We are still here and the child exited - that could mean trouble. */
-		tx_note("Failed to run a suitable web browser - if there's one installed on this system, please run it and forward yourself to:\nhttp://terminatorX.org", true);		
-		
-		gtk_idle_remove(browser_tag);
-		browser_tag=-1;
-	}
-	return TRUE;	
-}
-
 void display_browser()
 {	
 	browser_child=fork();
-
-	if (browser_tag!=-1) {
-		gtk_idle_remove(browser_tag);
-		if (browser_timer) g_timer_destroy(browser_timer);
-		browser_child=0;
-		browser_tag=-1;
-		browser_timer=NULL;
-	}
 	
 	if (browser_child==0) {
 		// child
-		execlp("mozilla","mozilla","http://terminatorX.org", NULL);
-		execlp("netscape","netscape","http://terminatorX.org", NULL);
-		execlp("galeon","galeon","http://terminatorX.org", NULL);
-		execlp("konqueror","konqueror","http://terminatorX.org", NULL);		
+		execlp(BROWSER1, BROWSER1, "http://terminatorX.org", NULL);
+		execlp(BROWSER2, BROWSER2, "http://terminatorX.org", NULL);
+		execlp(BROWSER3, BROWSER3, "http://terminatorX.org", NULL);
 		_exit(-1);
 	} else if (browser_child==-1) {
 		tx_note("System error: couldn't fork() to run the browser process.", true);
-	} else {
-		browser_timer=g_timer_new();
-		g_timer_start(browser_timer);
-	
-		browser_tag=gtk_idle_add((GtkFunction) browser_checker, NULL);
-	}
+	} 
 }
 
 
@@ -1955,7 +1919,7 @@ void tX_cursor::set_cursor(cursor_shape shape)
 	/* Still here? Ok... */
 	current_shape=shape;
 	
-	gdk_window_set_cursor(main_window->window, cursors[shape]);
+	gdk_window_set_cursor(gtk_widget_get_window(main_window), cursors[shape]);
 }
 
 GdkCursor *tX_cursor::get_cursor()
@@ -1966,5 +1930,5 @@ GdkCursor *tX_cursor::get_cursor()
 void tX_cursor::reset_cursor()
 {
 	current_shape=DEFAULT_CURSOR;
-	gdk_window_set_cursor(main_window->window, cursors[current_shape]);
+	gdk_window_set_cursor(gtk_widget_get_window(main_window), cursors[current_shape]);
 }
