@@ -13,29 +13,17 @@
   GNU General Public License for more details.
  
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  
   File: tX_midiin.cc
  
   Description: Implements MIDI input to control turntable parameters.
-  
-	Changes (Alexander König <alex@lisas.de>:
-	- Using a glib GIOCallback instead of polling events
-	- Updating the treeview immedialtey after bind/unbind_clicked
-	- Adding "remove binding" option
-	- Adding destroy handler for the GUI
-	- moving printf to tX_* macros
-	- removing some debug code
-	for 3.81
-	- re-connect to MIDI devices
-	- auto MIDI mappings
 */    
 
 #include "tX_midiin.h"
 #include "tX_vtt.h"
-#include "tX_glade_interface.h"
-#include "tX_glade_support.h"
+#include "tX_ui_interface.h"
+#include "tX_ui_support.h"
 #include "tX_dialog.h"
 #include "tX_mastergui.h"
 
@@ -302,12 +290,12 @@ tX_midiin::midi_binding_gui::midi_binding_gui ( GtkTreeModel* _model, tX_midiin*
 	gtk_widget_show (close_button);
 	gtk_box_pack_start (GTK_BOX (vbox1), close_button, FALSE, FALSE, 0);
 	
-	g_signal_connect(G_OBJECT(bind_button), "clicked", (GtkSignalFunc) bind_clicked, (void *) this);
-	g_signal_connect(G_OBJECT(unbind_button), "clicked", (GtkSignalFunc) unbind_clicked, (void *) this);	
-	g_signal_connect(G_OBJECT(close_button), "clicked", (GtkSignalFunc) close_clicked, (void *) this);
-	g_signal_connect(G_OBJECT(window), "destroy", (GtkSignalFunc) close_clicked, (void *) this);
+	g_signal_connect(G_OBJECT(bind_button), "clicked", (GCallback) bind_clicked, (void *) this);
+	g_signal_connect(G_OBJECT(unbind_button), "clicked", (GCallback) unbind_clicked, (void *) this);	
+	g_signal_connect(G_OBJECT(close_button), "clicked", (GCallback) close_clicked, (void *) this);
+	g_signal_connect(G_OBJECT(window), "destroy", (GCallback) close_clicked, (void *) this);
 	
-	timer_tag = gtk_timeout_add( 100, (GtkFunction) timer, (void *) this);
+	timer_tag = g_timeout_add( 100, (GSourceFunc) timer, (void *) this);
 	
 	gtk_widget_show_all( GTK_WIDGET( window ) );
 }
@@ -329,18 +317,22 @@ void tX_midiin::midi_binding_gui::unbind_clicked( GtkButton *button, gpointer _t
 	tX_seqpar* param;
 
 	selection = gtk_tree_view_get_selection( GTK_TREE_VIEW(this_->parameter_treeview) );
-	gtk_tree_selection_get_selected( selection, &model, &iter );
-	gtk_tree_model_get( model, &iter, 2, &param, -1 );
 	
-	param->bound_midi_event.type=tX_midievent::NONE;
-	param->bound_midi_event.number=0;
-	param->bound_midi_event.channel=0;
-	
-	snprintf( tmpstr, sizeof(tmpstr), "Type: %d, Number: %d, Channel: %d",
-				param->bound_midi_event.type, param->bound_midi_event.number,
-				param->bound_midi_event.channel );
+	if (gtk_tree_selection_get_selected( selection, &model, &iter)) {
+		gtk_tree_model_get( model, &iter, 2, &param, -1 );
+		
+		param->bound_midi_event.type=tX_midievent::NONE;
+		param->bound_midi_event.number=0;
+		param->bound_midi_event.channel=0;
+		
+		snprintf( tmpstr, sizeof(tmpstr), "Type: %d, Number: %d, Channel: %d",
+					param->bound_midi_event.type, param->bound_midi_event.number,
+					param->bound_midi_event.channel );
 
-	gtk_list_store_set(GTK_LIST_STORE(model), &iter, 0, param->get_name(), 1, tmpstr, 2, param, -1 );	
+		gtk_list_store_set(GTK_LIST_STORE(model), &iter, 0, param->get_name(), 1, tmpstr, 2, param, -1 );
+	} else {
+		tx_note("Please select a parameter to unbind first.", true, GTK_WINDOW(this_->window));
+	}
 }
 
 
@@ -354,16 +346,22 @@ void tX_midiin::midi_binding_gui::bind_clicked( GtkButton *button, gpointer _thi
 	tX_seqpar* param;
 
 	selection = gtk_tree_view_get_selection( GTK_TREE_VIEW(this_->parameter_treeview) );
-	gtk_tree_selection_get_selected( selection, &model, &iter );
-	gtk_tree_model_get( model, &iter, 2, &param, -1 );
 	
-	param->bound_midi_event = this_->last_event;
-	
-	snprintf( tmpstr, sizeof(tmpstr), "Type: %d, Number: %d, Channel: %d",
-				param->bound_midi_event.type, param->bound_midi_event.number,
-				param->bound_midi_event.channel );
-
-	gtk_list_store_set(GTK_LIST_STORE(model), &iter, 0, param->get_name(), 1, tmpstr, 2, param, -1 );	
+	if (gtk_tree_selection_get_selected( selection, &model, &iter )) {
+		gtk_tree_model_get( model, &iter, 2, &param, -1 );
+		if (this_->last_event.type != tX_midievent::NONE) {
+			param->bound_midi_event = this_->last_event;
+			snprintf( tmpstr, sizeof(tmpstr), "Type: %d, Number: %d, Channel: %d",
+					param->bound_midi_event.type, param->bound_midi_event.number,
+					param->bound_midi_event.channel );
+					
+			gtk_list_store_set(GTK_LIST_STORE(model), &iter, 0, param->get_name(), 1, tmpstr, 2, param, -1 );	
+		} else {
+			tx_note("Please send midi event to bind first.", true, GTK_WINDOW(this_->window));
+		}
+	} else {
+		tx_note("Please select a parameter to bind first.", true, GTK_WINDOW(this_->window));
+	}
 }
 
 void tX_midiin::midi_binding_gui::close_clicked( GtkButton *button, gpointer _this )
@@ -397,7 +395,7 @@ gint tX_midiin::midi_binding_gui::timer( gpointer _this )
 
 tX_midiin::midi_binding_gui::~midi_binding_gui ()
 {
-	gtk_timeout_remove( timer_tag );
+	g_source_remove( timer_tag );
 }
 
 void tX_midiin::set_midi_learn_sp(tX_seqpar *sp)
@@ -447,7 +445,7 @@ gboolean tX_midiin::midi_learn_destroy(GtkWidget *widget, tX_midiin *midi)
 
 void tX_midiin::store_connections(FILE *rc, char *indent) 
 {
-	gzFile *rz=NULL;
+	gzFile rz=NULL;
 	
 	tX_store("%s<midi_connections>\n", indent);
 
