@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2011  Alexander König
+    Copyright (C) 1999-2014  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
  
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
  
     File: tX_vtt.cc
  
@@ -41,6 +40,8 @@
 
 #include "tX_loaddlg.h"
 
+#include <string.h>
+
 #define USE_PREFETCH 1
 
 #ifdef USE_PREFETCH
@@ -1242,9 +1243,9 @@ int  vtt_class :: save(FILE *rc, gzFile rz, char *indent) {
 	store_float_sp("echo_pan", ec_pan, sp_ec_pan);
 	store_float_sp("echo_volume", ec_volume, sp_ec_volume);
 	
-	store_id("speed", sp_speed.get_persistence_id());
-	store_id("trigger", sp_trigger.get_persistence_id());
-	store_id("spin", sp_spin.get_persistence_id());
+	store_id_sp("speed", sp_speed);
+	store_id_sp("trigger", sp_trigger);
+	store_id_sp("spin", sp_spin);
 	
 	if (x_par) {
 		store_int("x_axis_mapping", x_par->get_persistence_id());
@@ -1325,8 +1326,6 @@ int vtt_class :: load(xmlDocPtr doc, xmlNodePtr node) {
 	int xpar_id=-1;
 	int ypar_id=-1;
 	int elementFound;
-	char *pid_attr;
-	int pid;
 	double dvalue;
 	double tmp;
 	char tmp_xml_buffer[4096];
@@ -1360,9 +1359,9 @@ int vtt_class :: load(xmlDocPtr doc, xmlNodePtr node) {
 			restore_float_id("echo_pan", ec_pan, sp_ec_pan, ec_set_pan(ec_pan));
 			restore_float_id("echo_volume", ec_volume, sp_ec_volume, ec_set_volume(ec_volume));		
 		
-			restore_id("speed", sp_speed);	
-			restore_id("trigger", sp_trigger);
-			restore_id("spin", sp_spin);
+			restore_sp_id("speed", sp_speed);	
+			restore_sp_id("trigger", sp_trigger);
+			restore_sp_id("spin", sp_spin);
 	
 			restore_int("x_axis_mapping", xpar_id);
 			restore_int("y_axis_mapping", ypar_id);
@@ -1388,18 +1387,13 @@ int vtt_class :: load(xmlDocPtr doc, xmlNodePtr node) {
 				
 				for (xmlNodePtr cur=fx->xmlChildrenNode; cur != NULL; cur = cur->next) {
 					if (cur->type == XML_ELEMENT_NODE) {
-						int elementFound=0;
-						
 						if ((xmlStrcmp(cur->name, (xmlChar *) "cutoff")==0) && !stereo) {
 							for (unsigned int t=0; t<fx_list.size(); t++) effect_down(lp_fx);
-							elementFound=1;
 						} else if ((xmlStrcmp(cur->name, (xmlChar *) "lowpass")==0) && !stereo) {
 							for (unsigned int t=0; t<fx_list.size(); t++) effect_down(ec_fx);
-							elementFound=1;								
 						} else if (xmlStrcmp(cur->name, (xmlChar *) "ladspa_plugin")==0) {
 							xmlNodePtr pluginNode=cur;
 							int ladspa_id=-1;
-							elementFound=1;
 							
 							for (xmlNodePtr cur=pluginNode->xmlChildrenNode; cur!=NULL; cur = cur->next) {
 								int elementFound;
