@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2011  Alexander König
+    Copyright (C) 1999-2014  Alexander König
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
  
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
  
     File: tX_vttgui.cc
  
@@ -22,16 +21,6 @@
     		 class implemented in tX_vtt.cc. This code is not in tX_vtt.cc
 		 for mainly to keep the GUI code divided from the audio-rendering
 		 code and as gtk+ callback to C++ method call wrapper.
-		 
-    Changes:
-    
-    before 11-26-2001: too many changes.
-    
-    11-26-2001: applied Adrian's solo/mute patch - Alex
-    
-    11-27-2001: modified solo/mute to use the set_mix_mute/solo function
-    		of the vtts. The previous approach messed up the sequencer
-		and more. Removed some old unnecessary code, too.
 */    
 
 #include <gdk/gdk.h>
@@ -49,8 +38,8 @@
 #include "tX_ladspa.h"
 #include "tX_ladspa_class.h"
 #include "tX_engine.h"
-#include "tX_glade_interface.h"
-#include "tX_glade_support.h"
+#include "tX_ui_interface.h"
+#include "tX_ui_support.h"
 #include "tX_dialog.h"
 
 #ifdef USE_DIAL
@@ -60,6 +49,7 @@
 #include "tX_flash.h"
 #include <stdio.h>
 #include <ctype.h>
+#include <string.h>
 
 #define WID_DYN TRUE, TRUE, 0
 #define WID_FIX FALSE, FALSE, 0
@@ -96,21 +86,21 @@ void name_changed(GtkWidget *wid, vtt_class *vtt)
 
 void volume_changed(GtkWidget *wid, vtt_class *vtt)
 {
-	vtt->sp_volume.receive_gui_value(2.0-GTK_ADJUSTMENT(wid)->value);
+	vtt->sp_volume.receive_gui_value(2.0-gtk_adjustment_get_value(GTK_ADJUSTMENT(wid)));
 }
 
 void pan_changed(GtkWidget *wid, vtt_class *vtt)
 {
-      vtt->sp_pan.receive_gui_value(GTK_ADJUSTMENT(wid)->value);
+      vtt->sp_pan.receive_gui_value(gtk_adjustment_get_value(GTK_ADJUSTMENT(wid)));
 }
 
 void pitch_changed(GtkWidget *wid, vtt_class *vtt)
 {
-	vtt->sp_pitch.receive_gui_value(GTK_ADJUSTMENT(wid)->value);
+	vtt->sp_pitch.receive_gui_value(gtk_adjustment_get_value(GTK_ADJUSTMENT(wid)));
 }
 
 #ifdef USE_FILECHOOSER
-GtkSignalFunc chooser_prelis(GtkWidget *w)
+GCallback chooser_prelis(GtkWidget *w)
 {
 	GtkFileChooser *fc=GTK_FILE_CHOOSER(gtk_widget_get_toplevel(w));
 	char *filename=gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fc));
@@ -124,7 +114,7 @@ GtkSignalFunc chooser_prelis(GtkWidget *w)
 	return NULL;
 }
 #else
-GtkSignalFunc trigger_prelis(GtkWidget *w)
+GCallback trigger_prelis(GtkWidget *w)
 {
 	GtkFileSelection *fs;
 
@@ -250,9 +240,9 @@ void drop_file(GtkWidget *widget, GdkDragContext *context,
 	char filename[PATH_MAX];
 	char *fn;
 	
-	strncpy(filename, (char *) selection_data->data, (size_t) selection_data->length);
+	strncpy(filename, (char *) gtk_selection_data_get_data(selection_data), (size_t) gtk_selection_data_get_length(selection_data));
 	gtk_drag_finish(context, TRUE, FALSE, time);
-	filename[selection_data->length]=0;
+	filename[gtk_selection_data_get_length(selection_data)]=0;
 
 	fn = strchr (filename, '\r');
 	*fn=0;	
@@ -265,7 +255,7 @@ void drop_file(GtkWidget *widget, GdkDragContext *context,
 		fn=realfn;
 	} else {
 		fn = strchr (filename, ':');
-		if (fn) fn++; else fn=(char *) selection_data->data;
+		if (fn) fn++; else fn=(char *) gtk_selection_data_get_data(selection_data);
 	}
 
 	load_part(fn, vtt);
@@ -274,10 +264,10 @@ void drop_file(GtkWidget *widget, GdkDragContext *context,
 	if (host) g_free(host);
 }
 
-GtkSignalFunc load_file(GtkWidget *wid, vtt_class *vtt)
+GCallback load_file(GtkWidget *wid, vtt_class *vtt)
 {	
 #ifdef USE_FILECHOOSER
-	const char *extensions[]={ "mp3", "wav", "ogg", "iff", "aiff", "voc", "au", NULL };
+	const char *extensions[]={ "mp3", "wav", "ogg", "flac", "iff", "aiff", "voc", "au", "spx", NULL };
 	char name_buf[512];
 	sprintf(name_buf, "Select Audio File for %s", vtt->name);
 	
@@ -369,7 +359,9 @@ void edit_vtt_buffer(GtkWidget *wid, vtt_class *vtt)
 		tx_note("No audiofile loaded - so there's nothing to edit.", true);
 	} else if (strlen(globals.file_editor)>0) {
 		sprintf(command, "%s \"%s\" &", globals.file_editor, vtt->filename);
-		int res = system(command); /*) tx_note("Failed to run the soundfile editor."); */
+		if (system(command) < 0) {
+			tx_note("Error running the soundfile editor.");
+		}
 	} else {
 		tx_note("No soundfile editor has been configured - to do so enter the soundfile editor of your choice in the options dialog.", true);
 	}
@@ -405,37 +397,37 @@ void stop_vtt(GtkWidget *wid, vtt_class *vtt)
 
 void autotrigger_toggled(GtkWidget *wid, vtt_class *vtt)
 {
-	vtt->set_autotrigger(GTK_TOGGLE_BUTTON(wid)->active);
+	vtt->set_autotrigger(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wid)));
 }
 
 void loop_toggled(GtkWidget *wid, vtt_class *vtt)
 {
-	vtt->sp_loop.receive_gui_value(GTK_TOGGLE_BUTTON(wid)->active);
+	vtt->sp_loop.receive_gui_value(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wid)));
 }
 
 void lp_enabled(GtkWidget *wid, vtt_class *vtt)
 {
-	vtt->sp_lp_enable.receive_gui_value(GTK_TOGGLE_BUTTON(wid)->active);
+	vtt->sp_lp_enable.receive_gui_value(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wid)));
 }
 
 void lp_gain_changed(GtkWidget *wid, vtt_class *vtt)
 {
-	vtt->sp_lp_gain.receive_gui_value(GTK_ADJUSTMENT(wid)->value);
+	vtt->sp_lp_gain.receive_gui_value(gtk_adjustment_get_value(GTK_ADJUSTMENT(wid)));
 }
 
 void lp_reso_changed(GtkWidget *wid, vtt_class *vtt)
 {
-	vtt->sp_lp_reso.receive_gui_value(GTK_ADJUSTMENT(wid)->value);
+	vtt->sp_lp_reso.receive_gui_value(gtk_adjustment_get_value(GTK_ADJUSTMENT(wid)));
 }
 
 void lp_freq_changed(GtkWidget *wid, vtt_class *vtt)
 {
-	vtt->sp_lp_freq.receive_gui_value(GTK_ADJUSTMENT(wid)->value);
+	vtt->sp_lp_freq.receive_gui_value(gtk_adjustment_get_value(GTK_ADJUSTMENT(wid)));
 }
 
 void ec_enabled(GtkWidget *wid, vtt_class *vtt)
 {
-	vtt->sp_ec_enable.receive_gui_value(GTK_TOGGLE_BUTTON(wid)->active);
+	vtt->sp_ec_enable.receive_gui_value(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wid)));
 }
 
 #ifdef USE_ALSA_MIDI_IN
@@ -447,27 +439,27 @@ void midi_mapping_clicked(GtkWidget *wid, vtt_class *vtt)
 
 void ec_length_changed(GtkWidget *wid, vtt_class *vtt)
 {
-	vtt->sp_ec_length.receive_gui_value(GTK_ADJUSTMENT(wid)->value);
+	vtt->sp_ec_length.receive_gui_value(gtk_adjustment_get_value(GTK_ADJUSTMENT(wid)));
 }
 
 void ec_feedback_changed(GtkWidget *wid, vtt_class *vtt)
 {
-	vtt->sp_ec_feedback.receive_gui_value(GTK_ADJUSTMENT(wid)->value);
+	vtt->sp_ec_feedback.receive_gui_value(gtk_adjustment_get_value(GTK_ADJUSTMENT(wid)));
 }
 
 void ec_pan_changed(GtkWidget *wid, vtt_class *vtt)
 {
-	vtt->sp_ec_pan.receive_gui_value(GTK_ADJUSTMENT(wid)->value);
+	vtt->sp_ec_pan.receive_gui_value(gtk_adjustment_get_value(GTK_ADJUSTMENT(wid)));
 }
 
 void ec_volume_changed(GtkWidget *wid, vtt_class *vtt)
 {
-	vtt->sp_ec_volume.receive_gui_value(GTK_ADJUSTMENT(wid)->value);
+	vtt->sp_ec_volume.receive_gui_value(gtk_adjustment_get_value(GTK_ADJUSTMENT(wid)));
 }
 
 void master_setup(GtkWidget *wid, vtt_class *vtt)
 {
-	vtt->set_sync_master(GTK_TOGGLE_BUTTON(wid)->active);
+	vtt->set_sync_master(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wid)));
 }
 
 void client_setup(GtkWidget *wid, vtt_class *vtt)
@@ -482,7 +474,7 @@ void client_setup_number(GtkWidget *wid, vtt_class *vtt)
 {
 	int cycles;
 	
-	cycles=(int) GTK_ADJUSTMENT(vtt->gui.cycles)->value;	
+	cycles=(int) gtk_adjustment_get_value(GTK_ADJUSTMENT(vtt->gui.cycles));
 	
 	vtt->sp_sync_cycles.receive_gui_value(cycles);
 }
@@ -705,7 +697,7 @@ static gint vg_file_button_pressed(GtkWidget *wid, GdkEventButton *event, vtt_cl
 
 void vg_adjust_zoom(GtkWidget *wid, vtt_class *vtt) {	
 	GtkAdjustment *adj=gtk_range_get_adjustment(GTK_RANGE(vtt->gui.zoom));
-	gtk_tx_set_zoom(GTK_TX(vtt->gui.display), adj->value/100.0);
+	gtk_tx_set_zoom(GTK_TX(vtt->gui.display), gtk_adjustment_get_value(adj)/100.0);
 }
 
 static gint fx_button_pressed(GtkWidget *wid, GdkEventButton *event, vtt_class *vtt)
@@ -990,8 +982,8 @@ void build_vtt_gui(vtt_class *vtt)
 	g->stop=gtk_button_new_with_label("Stop.");
 	gui_set_tooltip(g->stop, "Stop this turntable's playback.");
 	p->add_client_widget(g->stop);
-	g_signal_connect(G_OBJECT(g->trigger), "button_press_event", (GtkSignalFunc) tX_seqpar::tX_seqpar_press, &vtt->sp_trigger);		
-	g_signal_connect(G_OBJECT(g->stop), "button_press_event", (GtkSignalFunc) tX_seqpar::tX_seqpar_press, &vtt->sp_trigger);		
+	g_signal_connect(G_OBJECT(g->trigger), "button_press_event", (GCallback) tX_seqpar::tX_seqpar_press, &vtt->sp_trigger);		
+	g_signal_connect(G_OBJECT(g->stop), "button_press_event", (GCallback) tX_seqpar::tX_seqpar_press, &vtt->sp_trigger);		
 	
 	g->autotrigger=gtk_check_button_new_with_label("Auto");
 	p->add_client_widget(g->autotrigger);
@@ -1002,7 +994,7 @@ void build_vtt_gui(vtt_class *vtt)
 	p->add_client_widget(g->loop);
 	gui_set_tooltip(g->loop, "Enable this option to make the turntable loop the audio data.");
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(g->loop), vtt->loop);
-	g_signal_connect(G_OBJECT(g->loop), "button_press_event", (GtkSignalFunc) tX_seqpar::tX_seqpar_press, &vtt->sp_loop);		
+	g_signal_connect(G_OBJECT(g->loop), "button_press_event", (GCallback) tX_seqpar::tX_seqpar_press, &vtt->sp_loop);		
 	
 	g->sync_master=gtk_check_button_new_with_label("Master");
 	p->add_client_widget(g->sync_master);
@@ -1013,13 +1005,13 @@ void build_vtt_gui(vtt_class *vtt)
 	p->add_client_widget(g->sync_client);
 	gui_set_tooltip(g->sync_client, "If enabled this turntable will be (re-)triggerd in relation to the sync-master turntable.");
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(g->sync_client), vtt->is_sync_client);
-	g_signal_connect(G_OBJECT(g->sync_client), "button_press_event", (GtkSignalFunc) tX_seqpar::tX_seqpar_press, &vtt->sp_sync_client);	
+	g_signal_connect(G_OBJECT(g->sync_client), "button_press_event", (GCallback) tX_seqpar::tX_seqpar_press, &vtt->sp_sync_client);	
 	
 	g->cycles=GTK_ADJUSTMENT(gtk_adjustment_new(vtt->sync_cycles, 0, 10.0, 1,1,0));
 	dummy=gtk_spin_button_new(g->cycles, 1.0, 0);
 	p->add_client_widget(dummy);
 	gui_set_tooltip(dummy, "Determines how often a sync-client turntable gets triggered. 0 -> this turntable will be triggered with every trigger of the sync-master table, 1 -> the table will be triggered every 2nd master trigger and so on.");
-	g_signal_connect(G_OBJECT(dummy), "button_press_event", (GtkSignalFunc) tX_seqpar::tX_seqpar_press, &vtt->sp_sync_cycles);	
+	g_signal_connect(G_OBJECT(dummy), "button_press_event", (GCallback) tX_seqpar::tX_seqpar_press, &vtt->sp_sync_cycles);	
 
 	gtk_box_pack_start(GTK_BOX(g->control_subbox), p->get_widget(), WID_FIX);
 	
@@ -1044,7 +1036,7 @@ void build_vtt_gui(vtt_class *vtt)
 	gui_set_tooltip(g->lp_enable, "Click here to enable the built-in lowpass effect.");
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(g->lp_enable), vtt->lp_enable);
 	p->add_client_widget(vg_create_fx_bar(vtt, vtt->lp_fx, 0));
-	g_signal_connect(G_OBJECT(g->lp_enable), "button_press_event", (GtkSignalFunc) tX_seqpar::tX_seqpar_press, &vtt->sp_lp_enable);	
+	g_signal_connect(G_OBJECT(g->lp_enable), "button_press_event", (GCallback) tX_seqpar::tX_seqpar_press, &vtt->sp_lp_enable);	
 
 	p->add_client_widget(g->lp_enable);
 
@@ -1078,7 +1070,7 @@ void build_vtt_gui(vtt_class *vtt)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(g->ec_enable), vtt->ec_enable);
 	p->add_client_widget(g->ec_enable);
 	gui_set_tooltip(g->ec_enable, "Enable the built-in echo effect.");
-	g_signal_connect(G_OBJECT(g->ec_enable), "button_press_event", (GtkSignalFunc) tX_seqpar::tX_seqpar_press, &vtt->sp_ec_enable);	
+	g_signal_connect(G_OBJECT(g->ec_enable), "button_press_event", (GCallback) tX_seqpar::tX_seqpar_press, &vtt->sp_ec_enable);	
 
 	g->ec_length=GTK_ADJUSTMENT(gtk_adjustment_new(vtt->ec_length, 0, 1, 0.1, 0.01, 0.001));
 	g->ec_feedback=GTK_ADJUSTMENT(gtk_adjustment_new(vtt->ec_feedback, 0, 1, 0.1, 0.01, 0.001));
@@ -1141,13 +1133,13 @@ void build_vtt_gui(vtt_class *vtt)
 
 	g->mute=gtk_check_button_new_with_label("M");
 	gtk_box_pack_start(GTK_BOX(tempbox3), g->mute, WID_FIX);
-	g_signal_connect(G_OBJECT(g->mute),"clicked", (GtkSignalFunc) mute_volume, vtt);
+	g_signal_connect(G_OBJECT(g->mute),"clicked", (GCallback) mute_volume, vtt);
 	gtk_widget_show(g->mute);
 	gui_set_tooltip(g->mute, "Mute this turntable's mixer output.");
 
 	g->solo=gtk_check_button_new_with_label("S");
 	gtk_box_pack_start(GTK_BOX(tempbox3), g->solo, WID_FIX);
-	g_signal_connect(G_OBJECT(g->solo),"clicked", (GtkSignalFunc) solo_vtt, vtt);
+	g_signal_connect(G_OBJECT(g->solo),"clicked", (GCallback) solo_vtt, vtt);
 	gtk_widget_show(g->solo);
 	gui_set_tooltip(g->solo, "Allow only this and other solo-switched turntabels' signal to be routed to the mixer.");
 
@@ -1161,7 +1153,7 @@ void build_vtt_gui(vtt_class *vtt)
 	dummy=gtk_vscale_new(GTK_ADJUSTMENT(g->volume)); 
 	gtk_scale_set_draw_value(GTK_SCALE(dummy), False);
 	gui_set_tooltip(dummy, "Adjust this turntable's volume.");
-	g_signal_connect(G_OBJECT(dummy), "button_press_event", (GtkSignalFunc) tX_seqpar::tX_seqpar_press, &vtt->sp_volume);	
+	g_signal_connect(G_OBJECT(dummy), "button_press_event", (GCallback) tX_seqpar::tX_seqpar_press, &vtt->sp_volume);	
 
 	gtk_box_pack_start(GTK_BOX(tempbox2), dummy, WID_FIX);
 	gtk_widget_show(dummy);
@@ -1226,7 +1218,7 @@ GtkWidget *vg_create_fx_bar(vtt_class *vtt, vtt_fx *effect, int showdel)
 		gtk_box_pack_end(GTK_BOX(box), button, WID_FIX);
 		gtk_widget_show(pixmap);
 		gtk_widget_show(button);
-		g_signal_connect(G_OBJECT(button), "clicked", (GtkSignalFunc) fx_kill, (void *) effect);
+		g_signal_connect(G_OBJECT(button), "clicked", (GCallback) fx_kill, (void *) effect);
 	}
 
 	button=gtk_button_new();
@@ -1235,7 +1227,7 @@ GtkWidget *vg_create_fx_bar(vtt_class *vtt, vtt_fx *effect, int showdel)
 	gtk_box_pack_end(GTK_BOX(box), button, WID_FIX);
 	gtk_widget_show(pixmap);
 	gtk_widget_show(button);
-	g_signal_connect(G_OBJECT(button), "clicked", (GtkSignalFunc) fx_down, (void *) effect);
+	g_signal_connect(G_OBJECT(button), "clicked", (GCallback) fx_down, (void *) effect);
 
 	button=gtk_button_new();
 	pixmap=tx_pixmap_widget(FX_UP);
@@ -1243,7 +1235,7 @@ GtkWidget *vg_create_fx_bar(vtt_class *vtt, vtt_fx *effect, int showdel)
 	gtk_box_pack_end(GTK_BOX(box), button, WID_FIX);
 	gtk_widget_show(pixmap);
 	gtk_widget_show(button);
-	g_signal_connect(G_OBJECT(button), "clicked", (GtkSignalFunc) fx_up, (void *) effect);
+	g_signal_connect(G_OBJECT(button), "clicked", (GCallback) fx_up, (void *) effect);
 	
 	gtk_widget_show(box);
 	
@@ -1255,12 +1247,11 @@ int gtk_box_get_widget_pos(GtkBox *box, GtkWidget *child)
 	int i=0;
 	GList *list;
  
-	list = box->children;
+	list = gtk_container_get_children(GTK_CONTAINER(box));
 	while (list)
 	{
-		GtkBoxChild *child_info;
-		child_info = (GtkBoxChild *) list->data;
-		if (child_info->widget == child)
+		GtkWidget *child_widget = (GtkWidget *) list->data;
+		if (child_widget == child)
 		break;
 		list = list->next; i++;
     	}
@@ -1374,7 +1365,7 @@ void vg_create_fx_gui(vtt_class *vtt, vtt_fx_ladspa *effect, LADSPA_Plugin *plug
 			p->add_client_widget((*sp)->get_widget());
 	}
 
-	g_signal_connect(G_OBJECT(p->get_labelbutton()), "button_press_event", (GtkSignalFunc) vg_show_fx_menu, (void *) effect);
+	g_signal_connect(G_OBJECT(p->get_labelbutton()), "button_press_event", (GCallback) vg_show_fx_menu, (void *) effect);
 	gui_set_tooltip(p->get_labelbutton(), "Right-click to access menu.");
 	effect->set_panel_widget(p->get_widget());
 	effect->set_panel(p);
@@ -1400,7 +1391,7 @@ void gui_hide_control_panel(vtt_class *vtt, bool hide) {
 	if (hide) {
 		gtk_widget_hide(vtt->gui.control_box);
 		vtt->gui.control_minimized_panel_bar_button=tx_xpm_button_new(MIN_CONTROL, vtt->name, 0, &vtt->gui.control_minimized_panel_bar_label);
-		g_signal_connect(G_OBJECT(vtt->gui.control_minimized_panel_bar_button), "clicked", (GtkSignalFunc) unminimize_control_panel, vtt);
+		g_signal_connect(G_OBJECT(vtt->gui.control_minimized_panel_bar_button), "clicked", (GCallback) unminimize_control_panel, vtt);
 		gtk_widget_show(vtt->gui.control_minimized_panel_bar_button);
 		snprintf(tooltip, TOOLTIP_LENGTH, "Show \"%s\" control panel.", vtt->name);
 		gui_set_tooltip(vtt->gui.control_minimized_panel_bar_button, tooltip);
@@ -1419,7 +1410,7 @@ void gui_hide_audio_panel(vtt_class *vtt, bool hide) {
 	if (hide) {
 		gtk_widget_hide(vtt->gui.audio_box);
 		vtt->gui.audio_minimized_panel_bar_button=tx_xpm_button_new(MIN_AUDIO, vtt->name, 0, &vtt->gui.audio_minimized_panel_bar_label);
-		g_signal_connect(G_OBJECT(vtt->gui.audio_minimized_panel_bar_button), "clicked", (GtkSignalFunc) unminimize_audio_panel, vtt);		
+		g_signal_connect(G_OBJECT(vtt->gui.audio_minimized_panel_bar_button), "clicked", (GCallback) unminimize_audio_panel, vtt);		
 		gtk_widget_show(vtt->gui.audio_minimized_panel_bar_button);
 		snprintf(tooltip, TOOLTIP_LENGTH, "Show \"%s\" audio panel.", vtt->name);
 		gui_set_tooltip(vtt->gui.audio_minimized_panel_bar_button, tooltip);
